Index: include/asterisk/logger.h
===================================================================
--- include/asterisk/logger.h	(revision 84286)
+++ include/asterisk/logger.h	(working copy)
@@ -84,6 +84,8 @@
 
 void ast_console_puts_mutable(const char *string);
 void ast_console_toggle_mute(int fd);
+void ast_console_mute(int fd);
+void ast_console_unmute(int fd);
 
 #define _A_ __FILE__, __LINE__, __PRETTY_FUNCTION__
 
Index: main/asterisk.c
===================================================================
--- main/asterisk.c	(revision 84286)
+++ main/asterisk.c	(working copy)
@@ -832,14 +832,14 @@
 /*!
  * \brief mute or unmute a console from logging
  */
-void ast_console_toggle_mute(int fd) {
+static void __ast_console_set_mute(int fd, int mute) {
 	int x;
 	for (x = 0;x < AST_MAX_CONNECTS; x++) {
 		if (fd == consoles[x].fd) {
-			if (consoles[x].mute) {
+			if ((consoles[x].mute && mute == -1) || mute == 0) {
 				consoles[x].mute = 0;
 				ast_cli(fd, "Console is not muted anymore.\n");
-			} else {
+			} else if ((!consoles[x].mute && mute == -1) || mute == 1) {
 				consoles[x].mute = 1;
 				ast_cli(fd, "Console is muted.\n");
 			}
@@ -849,6 +849,18 @@
 	ast_cli(fd, "Couldn't find remote console.\n");
 }
 
+void ast_console_toggle_mute(int fd) {
+	__ast_console_set_mute(fd, -1);
+}
+
+void ast_console_mute(int fd) {
+	__ast_console_set_mute(fd, 1);
+}
+
+void ast_console_unmute(int fd) {
+	__ast_console_set_mute(fd, 0);
+}
+
 /*!
  * \brief log the string to all attached console clients
  */
@@ -2261,8 +2273,9 @@
 	snprintf(tmp, sizeof(tmp), "core set debug atleast %d", option_debug);
 	fdprint(ast_consock, tmp);
 	if (ast_opt_mute) {
-		snprintf(tmp, sizeof(tmp), "log and verbose output currently muted ('logger unmute' to unmute)");
+		snprintf(tmp, sizeof(tmp), "logger mute on");
 		fdprint(ast_consock, tmp);
+		ast_verbose("log and verbose output currently muted ('logger mute' to unmute)\n");
 	}
 	ast_verbose("Connected to Asterisk %s currently running on %s (pid = %d)\n", version, hostname, pid);
 	remotehostname = hostname;
Index: main/cli.c
===================================================================
--- main/cli.c	(revision 84286)
+++ main/cli.c	(working copy)
@@ -402,9 +402,17 @@
 
 static int handle_logger_mute(int fd, int argc, char *argv[])
 {
-	if (argc != 2)
+	if (argc == 2)
+		ast_console_toggle_mute(fd);
+	else if (argc == 3) {
+		if (!strcasecmp("on", argv[2]))
+			ast_console_mute(fd);
+		else if (!strcasecmp("off", argv[2]))
+			ast_console_unmute(fd);
+		else
+			return RESULT_SHOWUSAGE;
+	} else
 		return RESULT_SHOWUSAGE;
-	ast_console_toggle_mute(fd);
 	return RESULT_SUCCESS;
 }
 
